@@ -14,13 +14,29 @@ backups = 3
 package_name = "MaxCleanerDB"  # fixed folder name
 CORRUPT_TAG = ['!!<<CORRUPT_DATA_BLOCK::UNRECOVERABLE::ID#e3f7!!>>']
 
-import os
+# Prints a centered welcome message if 'MaxCleanerDB' is newly created.
+# previously done by create_package_and_get_txt_folder_path def
+main_package_path = os.path.join(current_dir, package_name)
+if not os.path.exists(main_package_path):
+    os.makedirs(main_package_path)
+
+    message = f"⭐ Welcome To {package_name}: Folder created at: {package_path}\n"
+    print("")
+    print(message)
+    
+    print("📌 Must Read 📌- import MaxCleanerDB as mdb \n")
+    
+    print("🔍 The visibility of the files in the backend is intentional for easier inspection.")
+    print("⚠️ Do NOT manually edit or tamper with them!")
+    print("📁 All 3 related files are required to have identical data.")
+    print("❌ Any mismatch will cause a read error.\n")
+    print("🛟 For Quick guide call MaxCleanerDB.help() or mdb.help() function\n")
+        
 
 def create_package_and_get_txt_folder_path(txt_name: str, position: str = "main") -> str:
     """
     Creates one of the folders 'MaxCleanerDB', 'MaxCleanerDB Snapshots', or 'MaxCleanerDB Backups'
     in the current working directory (where the function is called) if it doesn't exist.
-    Prints a centered welcome message if 'MaxCleanerDB' is newly created.
     Returns the full absolute path to txt_name inside that folder.
     """
     package_name = "MaxCleanerDB"  # Define the base package name
@@ -38,18 +54,6 @@ def create_package_and_get_txt_folder_path(txt_name: str, position: str = "main"
     folder_name = folder_map[position]
     package_path = os.path.join(current_dir, folder_name)
 
-    if not os.path.exists(package_path):
-        os.makedirs(package_path)
-
-        if position == "main":
-            message = f"⭐ Welcome To {package_name}: Folder created at: {package_path}"
-            try:
-                terminal_width = os.get_terminal_size().columns
-            except OSError:
-                terminal_width = 80
-            padding = (terminal_width - len(message)) // 2
-            print(' ' * max(padding, 0) + message)
-
     full_txt_path = os.path.join(package_path, txt_name)
     return full_txt_path
 
@@ -275,8 +279,8 @@ def validate_and_register_row_shape(items: list, validation: int | str | None, v
         if row_len != validation:
             raise IndexError(
                 f"Inconsistent row lengths Passed in the Parameter list at row {i}:\n"
-                f"            all rows must have the same number of elements/length {row}\n"
-                f"            Expected {validation} Length but got {row_len}."
+                f"            Expected {validation} Length but got {row_len} => {row}.\n"
+                f"            If using this in a loop, we suggest enclosing your data with [ ] to convert it into a 1D or 2D list."
             )
 
     if first_write is True:
